==> estateplat-common-1.2.4-20201113.090236-504-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlNydsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlNydsyq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlNydsyqBdc extends QlfQlNydsyq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dftdsyqxzdm;
    private String dftdsyqxzmc;
    private String dfsyttlxdm;
    private String dfsyttlxmc;
    private String dfyzyfsdm;
    private String dfyzyfsmc;

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFTDSYQXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDftdsyqxzdm() {
        return dftdsyqxzdm;
    }

    public void setDftdsyqxzdm(String dftdsyqxzdm) {
        this.dftdsyqxzdm = dftdsyqxzdm;
    }
    @XmlAttribute(
            name = "DFTDSYQXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDftdsyqxzmc() {
        return dftdsyqxzmc;
    }

    public void setDftdsyqxzmc(String dftdsyqxzmc) {
        this.dftdsyqxzmc = dftdsyqxzmc;
    }
    @XmlAttribute(
            name = "DFSYTTLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfsyttlxdm() {
        return dfsyttlxdm;
    }

    public void setDfsyttlxdm(String dfsyttlxdm) {
        this.dfsyttlxdm = dfsyttlxdm;
    }

    @XmlAttribute(
            name = "DFSYTTLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfsyttlxmc() {
        return dfsyttlxmc;
    }
    public void setDfsyttlxmc(String dfsyttlxmc) {
        this.dfsyttlxmc = dfsyttlxmc;
    }
    @XmlAttribute(
            name = "DFYZYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyzyfsdm() {
        return dfyzyfsdm;
    }

    public void setDfyzyfsdm(String dfyzyfsdm) {
        this.dfyzyfsdm = dfyzyfsdm;
    }
    @XmlAttribute(
            name = "DFYZYFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyzyfsmc() {
        return dfyzyfsmc;
    }

    public void setDfyzyfsmc(String dfyzyfsmc) {
        this.dfyzyfsmc = dfyzyfsmc;
    }
}

==> estateplat-common-1.2.4-20201116.061044-508-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlNydsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlNydsyq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlNydsyqBdc extends QlfQlNydsyq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dftdsyqxzdm;
    private String dftdsyqxzmc;
    private String dfsyttlxdm;
    private String dfsyttlxmc;
    private String dfyzyfsdm;
    private String dfyzyfsmc;

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFTDSYQXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDftdsyqxzdm() {
        return dftdsyqxzdm;
    }

    public void setDftdsyqxzdm(String dftdsyqxzdm) {
        this.dftdsyqxzdm = dftdsyqxzdm;
    }
    @XmlAttribute(
            name = "DFTDSYQXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDftdsyqxzmc() {
        return dftdsyqxzmc;
    }

    public void setDftdsyqxzmc(String dftdsyqxzmc) {
        this.dftdsyqxzmc = dftdsyqxzmc;
    }
    @XmlAttribute(
            name = "DFSYTTLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsyttlxdm() {
        return dfsyttlxdm;
    }

    public void setDfsyttlxdm(String dfsyttlxdm) {
        this.dfsyttlxdm = dfsyttlxdm;
    }

    @XmlAttribute(
            name = "DFSYTTLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsyttlxmc() {
        return dfsyttlxmc;
    }
    public void setDfsyttlxmc(String dfsyttlxmc) {
        this.dfsyttlxmc = dfsyttlxmc;
    }
    @XmlAttribute(
            name = "DFYZYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyzyfsdm() {
        return dfyzyfsdm;
    }

    public void setDfyzyfsdm(String dfyzyfsdm) {
        this.dfyzyfsdm = dfyzyfsdm;
    }
    @XmlAttribute(
            name = "DFYZYFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyzyfsmc() {
        return dfyzyfsmc;
    }

    public void setDfyzyfsmc(String dfyzyfsmc) {
        this.dfyzyfsmc = dfyzyfsmc;
    }
}
